@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -13,9 +13,16 @@
       global $mailbox, $imapConnection, $SQM_INTERNAL_VERSION;
       if (isset($SQM_INTERNAL_VERSION) && $SQM_INTERNAL_VERSION[1] == 5)
          return;
+
+      if (!defined('SM_PATH')) define('SM_PATH','../../../');
+
       if ($imapConnection) {
          $numMessages = sqimap_get_num_messages($imapConnection, $mailbox);
          if ($numMessages > 0) {
+	    // Set domain
+	    bindtextdomain ('archive_mail', SM_PATH . 'locale');
+	    textdomain ('archive_mail');
+
             if (@!function_exists('gzcompress')) {
                print "<table align=right><tr><td>";
                echo _("Archive disabled (zlib not supported)");
@@ -25,6 +32,10 @@
                echo _("Archive");
                print "'></p></td></tr>\n";
             }
+
+	    // Unset domain
+	    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+	    textdomain('squirrelmail');
          }
       }
 ?>
\ No newline at end of file
