@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -25,7 +25,11 @@
 
       global $username, $data_dir;
 
-      $filename = getHashedFile($username, $data_dir, "$username.pref");
+      // Set domain
+      bindtextdomain ('archive_mail', SM_PATH . 'locale');
+      textdomain ('archive_mail');
+
+      $filename = getHashedFile($username, $data_dir, '');
       $archivefilenames = getPref($filename, $username, 'archivefilenames');
       $archiveattachments = getPref($filename, $username, 'archiveattachments');
       $archivetype = getPref($filename, $username, 'archivetype');
@@ -58,7 +62,7 @@
       echo "<option value=0";
       if ($archiveent == 0)
          echo " SELECTED";
-      echo ">" . _("Seperate Entities") . "</option>\n";
+      echo ">" . _("Separate Entities") . "</option>\n";
 
       echo "</select><br>\n";
       echo "</td></tr>\n";
@@ -73,23 +77,23 @@
       echo ">&nbsp;" . _("No") . "</td>\n";
       echo "</tr>\n";
 
-      echo "<tr><td colspan=2><center><input type=submit name=submit value='Save'></form><center></td></tr>\n";
+      echo "<tr><td colspan=2><center><input type=submit name=submit value='" . _("Save") . "'></form><center></td></tr>\n";
       echo "<tr><td colspan=2><hr width='100%'></td></tr>\n";
 
       echo "<tr><td colspan=2><center><b>";
 
       switch ($archiveent) {
          case 0:
-            print "Seperate Entities Options";
+            print _("Separate Entities Options");
             break;
          case 1:
-            print "EML Messages Options";
+            print _("EML Messages Options");
             break;
          case 2:
-            print "Mbox Options";
+            print _("Mbox Options");
             break;
          case 3:
-            print "Maildir Options";
+            print _("Maildir Options");
             break;
       }
       echo "</b></center><br></td></tr>\n";
@@ -181,9 +185,13 @@
          echo "</td></tr>\n";
       }
 
-      echo "<tr><td colspan=2><center><input type=submit name=submit value='Save'></form></center></td></tr>\n";
+      echo "<tr><td colspan=2><center><input type=submit name=submit value='" . _("Save") . "'></form></center></td></tr>\n";
       echo '</table></center>';
 
+      // Unset domain
+      bindtextdomain('squirrelmail', SM_PATH . 'locale');
+      textdomain('squirrelmail');
+
       function getByteSize($ini_size) {
          if(!$ini_size) return FALSE;
          $ini_size = trim($ini_size);
