@@ -5,13 +5,20 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
 
 
     global $optpage_blocks;
+
+    if (!defined('SM_PATH')) define('SM_PATH','../../../');
+
+      // Set domain
+      bindtextdomain ('archive_mail', SM_PATH . 'locale');
+      textdomain ('archive_mail');
+
     $optpage_blocks[] = array (
         'name' => _("Archive Settings"),
         'url'  => '../plugins/archive_mail/includes/display_inside.php',
@@ -19,4 +26,7 @@
         'js'   => false
     );
 
+      // Unset domain
+      bindtextdomain('squirrelmail', SM_PATH . 'locale');
+      textdomain('squirrelmail');
 ?>
\ No newline at end of file
