@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -29,7 +29,7 @@
          setPref($data_dir, $username, 'archiveent', $archiveent);
 
          if ($archiveent != 2) {
-            $filename = getHashedFile($username, $data_dir, "$username.pref");
+            $filename = getHashedFile($username, $data_dir, '');
             $at = getPref($filename, $username, 'archivetype');
             if ($at == 2){
                $archivetype = 0;
