@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -14,7 +14,6 @@
                $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
                if ($response == 'OK') {
                   $c++;
-                  $k = $i + $start_index;
                   $seen = $msgs[$k]['FLAG_SEEN'];
                   if (!$seen)
                      sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
@@ -68,6 +67,8 @@
                   $dir = 'cur';
                   if (!$seen)
                      $dir = 'new';
+                  else
+                     $filename .= ':2,S';
                   $zipfile -> addFile($body, "$dir/$filename", $timestamp);
                }
 ?>
\ No newline at end of file
