@@ -5,13 +5,13 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.9
+    Version ........ 1.1
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
 
       global $username, $data_dir;
-      $filename = getHashedFile($username, $data_dir, "$username.pref");
+      $filename = getHashedFile($username, $data_dir, '');
       $archivefilenames = getPref($filename, $username, 'archivefilenames');
       if ($archivefilenames == '') {
          $archivefilenames = 6;
